package
Version:
v1.1.1
Opens a new window with list of versions in this module.
Published: May 16, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Output struct {
Score float64 `json:"score"`
Reason string `json:"reason"`
Issues []string `json:"issues,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.