request

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToEval

func ToEval(req gaugo.JudgeRequest) wire.EvalRequest

ToEval converts the public judge request into the internal wire request.

func ToRetry

func ToRetry(cfg gaugo.RetryConfig) wire.RetryConfig

ToRetry converts the public retry config into the internal wire shape.

Types

This section is empty.

Jump to